/*******************************************************************************
 * @file    stm32f4_discovery.h
 * @author  SOC Robotics, Inc. Development Team
 * @version V1.0.0
 * @date    07-November-2013
 * @brief   This file contains definitions for AQ32 Outputs and Inputs
 *
 * Code modified by SOC RObotics, Inc. to support the AQ32 UAV Control board.
 *
 * The changes in this file allow the AQ32 to output step/dir signals
 * and accept Limit Switch input to/from an external Stepper Motor controller.
 * Additional code has been added to support the MPU-600 accelerometer/gyrocompass,
 * HMC5883 magnetometer and MS5611 barometer.
 *
 * The original Discovery F4 code has been ported to the Coocox IDE V1.7.5 with USB support
 * built-in.  This code can be used as a starting point for further development.
 *
 * Step/Dir Output:
 *
 * 	STEPX	- PC9	- PWM 1
 * 	DIRX	- PC8	- PWM 2
 * 	STEPY	- PC7	- PWM 3
 * 	DIRY	- PC6	- PWM 4
 * 	STEPZ	- PA15	- PWM 5
 * 	DIRZ	- PB3	- PWM 6
 * 	STEPA	- PB4	- PWM 7
 * 	DIRA	- PB5	- PWM 8
 * 	STEPB	- PA0	- SRV 3
 * 	DIRB	- PA1	- SRV 2
 * 	STEPC	- PA2	- SRV 1
 * 	DIRC	- PA3	- SRV 0
 *
 * 	LIMITX	- PD12	- RF CH 1
 * 	LIMITY	- PD13	- RF CH 2
 * 	LIMITZ	- PD14	- RF CH 3
 * 	LIMITA	- PD15	- RF CH 4
 * 	LIMITB	- PE14	- RF CH 8
 * 	LIMITC	- PE13	- RF CH 7
 * 	ESTOP	- PE11	- RF CH 6
 *
 * 	Push button input in PA0 is changed to PC3 - AQ32 ADC 13
 *
 * *****************************************************************************/

/**
  ******************************************************************************
  * @file    stm32f4_discovery.h
  * @author  MCD Application Team
  * @version V1.0.0
  * @date    19-September-2011
  * @brief   This file contains definitions for STM32F4-Discovery Kit's Leds and
  *          push-button hardware resources.
  ******************************************************************************
  * @attention
  *
  * THE PRESENT FIRMWARE WHICH IS FOR GUIDANCE ONLY AIMS AT PROVIDING CUSTOMERS
  * WITH CODING INFORMATION REGARDING THEIR PRODUCTS IN ORDER FOR THEM TO SAVE
  * TIME. AS A RESULT, STMICROELECTRONICS SHALL NOT BE HELD LIABLE FOR ANY
  * DIRECT, INDIRECT OR CONSEQUENTIAL DAMAGES WITH RESPECT TO ANY CLAIMS ARISING
  * FROM THE CONTENT OF SUCH FIRMWARE AND/OR THE USE MADE BY CUSTOMERS OF THE
  * CODING INFORMATION CONTAINED HEREIN IN CONNECTION WITH THEIR PRODUCTS.
  *
  * <h2><center>&copy; COPYRIGHT 2011 STMicroelectronics</center></h2>
  ******************************************************************************  
  */
 
/* Define to prevent recursive inclusion -------------------------------------*/
#ifndef __STM32F4_DISCOVERY_H
#define __STM32F4_DISCOVERY_H

#ifdef __cplusplus
 extern "C" {
#endif
                                             
/* Includes ------------------------------------------------------------------*/
 #include "stm32f4xx.h"
   
/** @addtogroup Utilities
  * @{
  */
 
/** @addtogroup STM32F4_DISCOVERY
  * @{
  */
     
/** @addtogroup STM32F4_DISCOVERY_LOW_LEVEL
  * @{
  */

/** @defgroup STM32F4_DISCOVERY_LOW_LEVEL_Exported_Types
  * @{
  */
typedef enum
{
  LED4 = 0,
  LED3 = 1,
  LED5 = 2,
  LED6 = 3
} Led_TypeDef;

typedef enum
{
  STEPX = 0,
  STEPY = 1,
  STEPZ = 2,
  STEPA = 3,
  STEPB = 4,
  STEPC = 5
} Step_TypeDef;

typedef enum
{
  DIRX = 0,
  DIRY = 1,
  DIRZ = 2,
  DIRA = 3,
  DIRB = 4,
  DIRC = 5
} Dir_TypeDef;

typedef enum
{
  LIMITX = 0,
  LIMITY = 1,
  LIMITZ = 2,
  LIMITA = 3,
  LIMITB = 4,
  LIMITC = 5,
  ESTOP = 6
} Limit_TypeDef;

typedef enum
{  
  BUTTON_USER = 0,
} Button_TypeDef;

typedef enum
{  
  BUTTON_MODE_GPIO = 0,
  BUTTON_MODE_EXTI = 1
} ButtonMode_TypeDef;    
/**
  * @}
  */

/** @defgroup STM32F4_DISCOVERY_LOW_LEVEL_Exported_Constants
  * @{
  */

/** @addtogroup STM32F4_DISCOVERY_LOW_LEVEL_LED
  * @{
  */
#define LEDn                             4

#define LED4_PIN                         GPIO_Pin_5
#define LED4_GPIO_PORT                   GPIOE
#define LED4_GPIO_CLK                    RCC_AHB1Periph_GPIOE
 
#define LED3_PIN                         GPIO_Pin_6
#define LED3_GPIO_PORT                   GPIOE
#define LED3_GPIO_CLK                    RCC_AHB1Periph_GPIOE
 
#define LED5_PIN                         GPIO_Pin_0
#define LED5_GPIO_PORT                   GPIOE
#define LED5_GPIO_CLK                    RCC_AHB1Periph_GPIOE
 
#define LED6_PIN                         GPIO_Pin_1
#define LED6_GPIO_PORT                   GPIOE
#define LED6_GPIO_CLK                    RCC_AHB1Periph_GPIOE
/**
  * @}
  */
 
/** @addtogroup STM32F4_DISCOVERY_LOW_LEVEL_BUTTON
  * @{
  */  
#define BUTTONn                          1  

/**
 * @brief Wakeup push-button - On AQ32 this is A/D input PC3 which can
 * be used as either a digital or analog input - in this case it's a digital input
 */
#define USER_BUTTON_PIN                GPIO_Pin_3
#define USER_BUTTON_GPIO_PORT          GPIOC
#define USER_BUTTON_GPIO_CLK           RCC_AHB1Periph_GPIOC
#define USER_BUTTON_EXTI_LINE          EXTI_Line0
#define USER_BUTTON_EXTI_PORT_SOURCE   EXTI_PortSourceGPIOC
#define USER_BUTTON_EXTI_PIN_SOURCE    EXTI_PinSource0
#define USER_BUTTON_EXTI_IRQn          EXTI0_IRQn

// Define Motor Control Outputs
#define STEPn							 6
#define DIRn							 6

#define STEPX_PIN                         GPIO_Pin_9
#define STEPX_GPIO_PORT                   GPIOC
#define STEPX_GPIO_CLK                    RCC_AHB1Periph_GPIOC
#define DIRX_PIN                          GPIO_Pin_8
#define DIRX_GPIO_PORT                    GPIOC
#define DIRX_GPIO_CLK                     RCC_AHB1Periph_GPIOC

#define STEPY_PIN                         GPIO_Pin_7
#define STEPY_GPIO_PORT                   GPIOC
#define STEPY_GPIO_CLK                    RCC_AHB1Periph_GPIOC
#define DIRY_PIN                          GPIO_Pin_6
#define DIRY_GPIO_PORT                    GPIOC
#define DIRY_GPIO_CLK                     RCC_AHB1Periph_GPIOC

#define STEPZ_PIN                         GPIO_Pin_15
#define STEPZ_GPIO_PORT                   GPIOA
#define STEPZ_GPIO_CLK                    RCC_AHB1Periph_GPIOA
#define DIRZ_PIN                          GPIO_Pin_3
#define DIRZ_GPIO_PORT                    GPIOB
#define DIRZ_GPIO_CLK                     RCC_AHB1Periph_GPIOB

#define STEPA_PIN                         GPIO_Pin_4
#define STEPA_GPIO_PORT                   GPIOB
#define STEPA_GPIO_CLK                    RCC_AHB1Periph_GPIOB
#define DIRA_PIN                          GPIO_Pin_5
#define DIRA_GPIO_PORT                    GPIOB
#define DIRA_GPIO_CLK                     RCC_AHB1Periph_GPIOB

#define STEPB_PIN                         GPIO_Pin_0
#define STEPB_GPIO_PORT                   GPIOA
#define STEPB_GPIO_CLK                    RCC_AHB1Periph_GPIOA
#define DIRB_PIN                          GPIO_Pin_1
#define DIRB_GPIO_PORT                    GPIOA
#define DIRB_GPIO_CLK                     RCC_AHB1Periph_GPIOA

#define STEPC_PIN                         GPIO_Pin_2
#define STEPC_GPIO_PORT                   GPIOA
#define STEPC_GPIO_CLK                    RCC_AHB1Periph_GPIOA
#define DIRC_PIN                          GPIO_Pin_3
#define DIRC_GPIO_PORT                    GPIOA
#define DIRC_GPIO_CLK                     RCC_AHB1Periph_GPIOA

// Define Limit Switch input pins
#define LIMITn							  7

#define LIMITX_PIN                        GPIO_Pin_12
#define LIMITX_GPIO_PORT                  GPIOD
#define LIMITX_GPIO_CLK                   RCC_AHB1Periph_GPIOD

#define LIMITY_PIN                        GPIO_Pin_13
#define LIMITY_GPIO_PORT                  GPIOD
#define LIMITY_GPIO_CLK                   RCC_AHB1Periph_GPIOD

#define LIMITZ_PIN                        GPIO_Pin_14
#define LIMITZ_GPIO_PORT                  GPIOD
#define LIMITZ_GPIO_CLK                   RCC_AHB1Periph_GPIOD

#define LIMITA_PIN                        GPIO_Pin_15
#define LIMITA_GPIO_PORT                  GPIOD
#define LIMITA_GPIO_CLK                   RCC_AHB1Periph_GPIOD

#define LIMITB_PIN                        GPIO_Pin_14
#define LIMITB_GPIO_PORT                  GPIOE
#define LIMITB_GPIO_CLK                   RCC_AHB1Periph_GPIOE

#define LIMITC_PIN                        GPIO_Pin_13
#define LIMITC_GPIO_PORT                  GPIOE
#define LIMITC_GPIO_CLK                   RCC_AHB1Periph_GPIOE

#define ESTOP_PIN                         GPIO_Pin_11
#define ESTOP_GPIO_PORT                   GPIOE
#define ESTOP_GPIO_CLK                    RCC_AHB1Periph_GPIOE

/**
  * @}
  */
 
/** @defgroup STM32F4_DISCOVERY_LOW_LEVEL_Exported_Macros
  * @{
  */  
/**
  * @}
  */


/** @defgroup STM32F4_DISCOVERY_LOW_LEVEL_Exported_Functions
  * @{
  */
void AQ32_LEDInit(Led_TypeDef Led);
void AQ32_LEDOn(Led_TypeDef Led);
void AQ32_LEDOff(Led_TypeDef Led);
void AQ32_LEDToggle(Led_TypeDef Led);
void AQ32_PBInit(Button_TypeDef Button, ButtonMode_TypeDef Button_Mode);
uint32_t AQ32_PBGetState(Button_TypeDef Button);
uint32_t AQ32_Limit_GetState(Limit_TypeDef Limit);

void AQ32_Motor_Step_High(Step_TypeDef Step);
void AQ32_Motor_Step_Low(Step_TypeDef Step);
void AQ32_Motor_Dir_High(Step_TypeDef Dir);
void AQ32_Motor_Dir_Low(Step_TypeDef Dir);
/**
  * @}
  */
 
#ifdef __cplusplus
}
#endif

#endif /* __STM32F4_DISCOVERY_H */
/**
  * @}
  */

/**
  * @}
  */

/**
  * @}
  */

 

/******************* (C) COPYRIGHT 2011 STMicroelectronics *****END OF FILE****/
